<?php

namespace App\Classes\LDAP\Attribute;

use App\Classes\LDAP\Attribute;

/**
 * Represents an attribute whose values are binary
 */
abstract class Binary extends Attribute
{
}